// GPIBlib_HP_3325A.h - HP 3325A Synthesiser/Function Generator.
//==============================================================

// Frequency units

#define FREQ_HZ    1
#define FREQ_KHZ   2
#define FREQ_MHZ   3
#define FREQ_GHZ   4

// Amplitude units

#define AMP_V      1
#define AMP_MV     2
#define AMP_V_PP   3
#define AMP_MV_PP  4
#define AMP_V_RMS  5
#define AMP_MV_RMS 6
#define AMP_DBM    7

// Sweep modes.

#define SWEEP_LINEAR 1
#define SWEEP_LOG    2

// Waveforms

#define WAVE_DC        0
#define WAVE_SINE      1
#define WAVE_SQUARE    2
#define WAVE_TRIANGLE  3
#define WAVE_RAMP_UP   4
#define WAVE_RAMP_DOWN 5

// Modulation

#define MOD_NONE      0  // No modulation
#define MOD_AMP       1  // Amplitude modulation.
#define MOD_PHASE     2  // Phase modulation.

// C++ Class.

class Gpib_HP_3325A : public GpibInstrument
{
public:
  Gpib_HP_3325A( int address, int gpibif=0 );
  virtual ~Gpib_HP_3325A();

  bool check_open( void );
  bool check_error( void );

  bool set_function( int waveform );
  bool set_frequency( float freq, int units=FREQ_HZ );
  bool set_amplitude( float amp, int units=AMP_V_PP );
  bool set_dc_offset( float dc, int units=AMP_V );
  bool set_phase( float degrees );

  bool set_sweep_start_frequency( float freq, int units=FREQ_HZ );
  bool set_sweep_end_frequency( float freq, int units=FREQ_HZ );
  bool set_sweep_marker_frequency( float freq, int units=FREQ_HZ );
  bool set_sweep_mode( int sweep_mode );
  bool set_sweep_time( float secs );

  bool start_sweep_single( bool waitfin=false );

  bool start_sweep_continuous( void );

  bool use_amplitude_modulation( bool yes );
  bool use_phase_modulation( bool yes );

public:
  bool _hp3325a_opened;
  GpibHandle _hp3325a;
  int _waveform;        // Waveform type.
  float _freq;          // Frequency (Hertz).
  float _amp;           // Amplitude (Volts, Peak-Peak).
  float _dc;            // DC offset (Volts).
  float _phase;         // Phase offset (Degrees).
  float _sweep_start;   // Sweep start frequency (Hertz).
  float _sweep_end;     // Sweep end frequency (Hertz).
  float _sweep_marker;  // Sweep marker frequency (Hertz).
  int _sweep_mode;      // Sweep mode (lin or log).
  float _sweep_time;    // Sweep time.
  int _modulate;        // Modulation.
  int _instrument_err;  // Error number returned from the 3325A.
};
