// GPIBlib_HP_3582A.h - HP 3582A Spectrum Analyzer
// ===============================================

// HP3582A Frequency ranges.

#define FULL_SPAN     1  // 0-25kHz
#define ZERO_START    2
#define SET_START     4
#define SET_CENTER    3

// HP3582A display modes

#define LINEAR        1
#define LOG10DB       2
#define LOG2DB        3

// HP3582A Passband windows

#define FLATTOP       1
#define HANNING       2
#define UNIFORM       3

// HP3582A Averaging and measurement counts

#define AVERAGE_OFF   1
#define AVERAGE_RMS   2

// C++ Class.

class Gpib_HP_3582A : public GpibInstrument
{
public:
  Gpib_HP_3582A( int address, int gpibif=0 );
  virtual ~Gpib_HP_3582A();
  bool check_open( void );

  // Input modes
  bool set_input_mode( int channels );
  bool coupling( int channel, int mode );

  // Input sensitivity
  bool set_sensitivity( int channel, double volts );
  bool set_sensitivity_db( int channel, double volts );

  // Frequency range.
  bool set_frequency( int mode, double span, double freq );

  // Display
  bool display( int channels, int ymode );
  bool set_amp_ref_level_db( double refdb );

  double get_amp_ref_level_db( void );

  // Window function.
  bool window( int windowtype );

  // Set measurement mode.
  bool start_measurement( int avtype, int count, int maxloop=50 );
  bool read_status( void );

  // Read data.
  bool read_data( int& ndata, double* data, int maxdata );
  bool read_annotation( int& ndata, char* text, int maxtext );

  // Get a measured spectrum.
  bool get_spectrum( double* freq, double* cha, double* chb, int& nsamp, bool& a_avail, bool& b_avail );

private:
  int freq_to_span( double span );

public:
  bool _hp3582a_opened;
  GpibHandle _hp3582a;

  int _instrument_err; // Error returned from 3582A.

public:
  double _data[512]; // Spectrum or time record returned by 3582A
  int _ndata;        // Number of data points stored in _data[].
  char _annot[140];  // Display annotation from 3582A

  int _disp_chan;    // CHA CHB or CHBOTH being displayed and readable.
  int _inp_chan;     // CHA CHB or CHBOTH being selected for input.
  double _frlo;      // Spectrum start frequency.
  double _frhi;      // Spectrum end frequency.
  double _ampref;    // Amplitude reference level.
};
