// GPIBlib_TEK_RTD710A.h - Sony/Tektronix RTD-710A Digitizer
// =========================================================

// C++ Class.

class Gpib_TEK_RTD710A : public GpibInstrument
{
public:
  Gpib_TEK_RTD710A( int address, int gpibif=0 );
  virtual ~Gpib_TEK_RTD710A();
  bool check_open( void );

  // Vertical axis
  bool range( int chan, double volts );
  bool offset( int chan, double volts );
  bool coupling( int chan, int coupling );
  bool bw_limit( bool yes );
  bool ch1_only( bool yes );

  // Horizontal axis
  bool sample_interval( double time );
  bool samples( int samples );
  bool sample_hold( bool yes );

  // Triggering
  bool trigger_mode( int mode );
  bool trigger_source( int source );
  bool trigger_coupling( int coupling );
  bool trigger_slope( int slope );
  bool trigger_level( double percent, int which );

  // Recording
  bool record_to( int location );
  bool record_mode( int mode, int times );

  // Display
  bool display_from( int chan, int location );
  bool display_hzoom( int zoom );
  bool display_vzoom( int zoom );
  bool display_vpos( int pos );

  // Get waveform
  bool record_wave( int waitms );
  bool read_wave( int location, int chan, double* wave, int& npoints, double& tstep );

public:
  bool _rtd710a_opened;
  GpibHandle _rtd710a;

  int _instrument_err; // Error returned from RTD-710A.

private:
  double round_volts( double volts );
  int get_int_query( const char* query );
  int get_int_query_sep( const char* query, char sep );
  double get_double_query( const char* query );

  int block[2*1024+10]; // Curve data from RTD-710A
};
